==> jc-1.4.0.tar.gz: soot/jimple/internal/JShrExpr.h <==
// public class soot.jimple.internal.JShrExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr
// @dep_class 2edcd395b8ec24b3 soot_jimple_internal_AbstractJimpleIntLongBinopExpr
// @dep_class a6e453e764f7009a soot_jimple_internal_JShrExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractJimpleIntLongBinopExpr

#include "soot/jimple/internal/AbstractJimpleIntLongBinopExpr.h"

#ifndef _JC_soot_jimple_internal_JShrExpr_H_
#define _JC_soot_jimple_internal_JShrExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JShrExpr$sub_refs	_jc_soot_jimple_internal_JShrExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JShrExpr$sub_nonrefs	_jc_soot_jimple_internal_JShrExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JShrExpr$refs	_jc_soot_jimple_internal_JShrExpr$refs;
typedef struct _jc_soot_jimple_internal_JShrExpr$nonrefs	_jc_soot_jimple_internal_JShrExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JShrExpr$object	_jc_soot_jimple_internal_JShrExpr$object;

typedef const struct _jc_soot_jimple_internal_JShrExpr$vmethods	_jc_soot_jimple_internal_JShrExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JShrExpr$vtable	_jc_soot_jimple_internal_JShrExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JShrExpr$vtype	_jc_soot_jimple_internal_JShrExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JShrExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_internal_JShrExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JShrExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JShrExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JShrExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JShrExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JShrExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JShrExpr$method_info$getSymbol$ce407d9fb7da8b41;
extern _jc_method _jc_soot_jimple_internal_JShrExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_JShrExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *);
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *);
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JShrExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
	_jc_soot_jimple_internal_JShrExpr$vmethods	soot_jimple_internal_JShrExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JShrExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JShrExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JShrExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JShrExpr$refs {
    _jc_soot_jimple_internal_JShrExpr$sub_refs	soot_jimple_internal_JShrExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JShrExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JShrExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_JShrExpr$sub_nonrefs	soot_jimple_internal_JShrExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JShrExpr$object {
	_jc_soot_jimple_internal_JShrExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JShrExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JShrExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JShrExpr$vtype _jc_soot_jimple_internal_JShrExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JShrExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JShrExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JShrExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JShrExpr.h <==
// public class soot.jimple.internal.JShrExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr
// @dep_class 2edcd395b8ec24b3 soot_jimple_internal_AbstractJimpleIntLongBinopExpr
// @dep_class a6e453e764f7009a soot_jimple_internal_JShrExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractJimpleIntLongBinopExpr

#include "soot/jimple/internal/AbstractJimpleIntLongBinopExpr.h"

#ifndef _JC_soot_jimple_internal_JShrExpr_H_
#define _JC_soot_jimple_internal_JShrExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JShrExpr$sub_refs	_jc_soot_jimple_internal_JShrExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JShrExpr$sub_nonrefs	_jc_soot_jimple_internal_JShrExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JShrExpr$refs	_jc_soot_jimple_internal_JShrExpr$refs;
typedef struct _jc_soot_jimple_internal_JShrExpr$nonrefs	_jc_soot_jimple_internal_JShrExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JShrExpr$object	_jc_soot_jimple_internal_JShrExpr$object;

typedef const struct _jc_soot_jimple_internal_JShrExpr$vmethods	_jc_soot_jimple_internal_JShrExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JShrExpr$vtable	_jc_soot_jimple_internal_JShrExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JShrExpr$vtype	_jc_soot_jimple_internal_JShrExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JShrExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_JShrExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JShrExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JShrExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JShrExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JShrExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JShrExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JShrExpr$method_info$getSymbol$ce407d9fb7da8b41;
extern _jc_method _jc_soot_jimple_internal_JShrExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_JShrExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_JShrExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JShrExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
	_jc_soot_jimple_internal_JShrExpr$vmethods	soot_jimple_internal_JShrExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JShrExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JShrExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JShrExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JShrExpr$refs {
    _jc_soot_jimple_internal_JShrExpr$sub_refs	soot_jimple_internal_JShrExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JShrExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JShrExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_JShrExpr$sub_nonrefs	soot_jimple_internal_JShrExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JShrExpr$object {
	_jc_soot_jimple_internal_JShrExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JShrExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JShrExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JShrExpr$vtype _jc_soot_jimple_internal_JShrExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JShrExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JShrExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JShrExpr_H_ */
